/**********************************************************************************************/
/* VDK_Text.h																				  */
/*                                                                       					  */
/* Valentina SDK    																		  */
/*                                                                       					  */
/* Copyright Paradigma, 1993-2002															  */
/* All Rights Reserved                                                   					  */
/**********************************************************************************************/

#ifndef __VDK_Text_h 
	#define __VDK_Text_h
	
#if VSDK_FRAMEWORK_STYLE
#	include <VSDK/VDK_BLOB.h>
#	include <VSDK/FBL_StringUtilities.h>
#else
#	include <VDK_BLOB.h>
#	include <FBL_StringUtilities.h>
#endif // VSDK_FRAMEWORK_STYLE

#if defined(__MWERKS__)
	#pragma options align=power
#endif


/**********************************************************************************************/
// Valentina store strings in the indexes as varaible length pascal strings always.

// VDK_String 	stores strings in the table as fixed length strings
// VDK_VarChar 	stores strings in the tables as variable length strings.
// VDK_Text 	stores strings as BLOB objects (also variable length, based on segments).
// VDK_Byte 	is most effective to store strings with length 1 character.

/**********************************************************************************************/
class FBL_EXP VDK_Text : public virtual VDK_BLOB
{
		friend class VDK_BaseObject;

	public://///////////////////////////////////////////////////////////////////////////////////
		
							 	// inBlockSize will be used only once - 
								// on create of blob file. It can't be changed runtime. 
FBL_EXP							VDK_Text( 
									const char* inName, 
									ulong		inBlockSize = 10 * 1024,
									ushort		inFlags	= 0 );	

		
		// Methodes for international support: 
		// Used only for indexed Text field.

FBL_EXP	virtual FBL_Language*	GetLanguage( void ) const;
		
								// number of itl2 resource, 
								// if -1 then byte-to-byte comparision is used.
FBL_EXP	virtual void			SetLanguage( 
									const char*	inLanguage,
									bool		inSaveOnDisk = true );

FBL_EXP	virtual void			SetCompareFunction( FBL_CompareStringPtr inCompare ); 		

		/* Search methods */
		
FBL_EXP	FBL_BitSet*				Find( const char* inLeftValue , bool inLeftInclude, 
									  const char* inRightValue, bool inRightInclude );
		
FBL_EXP	FBL_BitSet* 			Find( const char* inKey = NULL );
		
FBL_EXP	virtual FBL_BitSet*		SearchLike( const char* inValue, bool inMatchCase = true );
FBL_EXP	virtual FBL_BitSet*		SearchRegEx( const char* inValue, bool inMatchCase = true );


	protected://////////////////////////////////////////////////////////////////////////////////

FBL_EXP virtual void			FinishCreateSelf( void );

	protected://////////////////////////////////////////////////////////////////////////////////
		 
	 	FBL_Language*			mLanguage;
}; 


/**********************************************************************************************/
#if defined(__MWERKS__)
	#pragma options align=reset
#endif

#endif  


